I would like to create a CR to console window, you can reference console-explorer.png that, if I click + it should create a session for me, and I can create at least 10 sessions.

1. now I no longer want side by side sessions.
2. now I would like have only selected session show in console window. and non-selected console running in backend.
3. I can click related session in session explorer to swtich sessions.
4. after create the session it should have defaut name, but there should be edit icon on each session bar. I can click it to edit session name.
5. when I hover on the session bar for 0.5 second, it should popup a preview modal window, so I can see what's going on with the console content.